# coding=utf-8
import datetime

from filmweb.parser.ObjectParser import ObjectParser
from filmweb.func import get_real_id
from filmweb.func import get_canonical_name


class PersonParser(ObjectParser):
    def _parse_basic(self):
        dic = {}

        poster = self.soup.find("img", "personBigPhoto")
        if poster['src'].find("plug.svg") == -1:
            dic['poster'] = poster['src']
        else:
            dic['poster'] = None

        title = poster['alt'].strip()
        dic['title'] = title
        dic['canonicalname'] = get_canonical_name(dic['title'])

        more_info = self.soup.find("div", "personInfo")

        if more_info:
            for more in more_info.findAll('tr'):
                name = more.find('th')
                value = more.find('td')
                js = value.find('script')
                if js:
                    js.extract()
                dic[name.text.replace(":", "")] = value.text

            if dic.get('data urodzenia', None):
                try:
                    dic['birthdate'] = datetime.datetime.strptime(dic['data urodzenia'], "%Y-%m-%d")  # 1923-03-13
                except ValueError:
                    dic['birthdate'] = None

            if dic.get('data śmierci', None):
                try:
                    dic['deaddate'] = datetime.strptime(dic['data śmierci'], "%Y-%m-%d")
                except ValueError:
                    dic['deaddate'] = None
        return dic

    def parse_filmography(self):
        from filmweb.Movie import Movie

        movie_links = self.soup.findAll("tr", {'data-type': "F"})

        movies = []
        for movie_link in movie_links:
            a = movie_link.find("a")
            movieID = get_real_id(a['href'])
            movies.append(Movie(objID=movieID, title=a.text, url=a['href']))
        return movies




# coding=utf-8

filmweb_root = 'http://www.filmweb.pl'

filmweb_movie_link = filmweb_root + "/film/%s-%d-%d"  # name,year,id
filmweb_person_link = filmweb_root + "/person/%s-%d"  # name,id

filmweb_search_blank = filmweb_root + '/search'
filmweb_search = filmweb_root + '/search?q=%s&page=%d'
filmweb_movie_search = filmweb_root + "/search/%s?q=%s&page=%d&genreIds="
filmweb_person_search = filmweb_root + "/search/person?q=%s&page=%d"

filmweb_person_link = filmweb_root + "/person/%s-%d"


# coding=utf-8
try:
    from urlparse import urljoin
except:
    from urllib.parse import urljoin

from filmweb.vars import filmweb_root


class BaseObject(object):
    def __init__(self, objID, title=None, url=None, roleType=None, roleName=None):
        self.reset()
        self.set_id(objID)
        self.set_url(url)
        self.parser_obj = self.parser()
        self.set_title(title)

        self['roleName'] = roleName
        self['roleType'] = roleType

    def reset(self):
        self.data = {}
        self.objID = None
        self.title = None
        self.url = None

    def get(self, key, default=None):
        try:
            if self[key]:
                return self[key]
            else:
                return default
        except:
            return default

    def __getitem__(self, key):
        """Return the value for a given key"""

        if key in self.data:
            return self.data[key]
        else:

            if key in ('title', 'year', 'title_original', 'desc', 'poster', 'birthdate', 'deaddate', 'canonicalname'):
                dic = self.parser_obj.parse_basic()
                self.set_data(dic)
            elif key == 'url':
                self[key] = self.parser_obj.parse_real_url()
            else:
                method = getattr(self.parser_obj, 'parse_' + key)
                self[key] = method()
            return self.data[key]

    def __setitem__(self, key, item):
        """Store the item with the given key."""
        self.data[key] = item

    def __delitem__(self, key):
        """Remove the given key."""
        del self.data[key]

    def __eq__(self, other):
        return self.objID == other.objID

    def parser(self):
        return self._parser()

    def set_data(self, data):
        self.data.update(data)

    def set_url(self, url):
        if url is not None:
            self.url = urljoin(filmweb_root, url).strip()
        else:
            self.url = self.get_url()

    def _get_url(self):
        """Return movie, person url"""
        raise NotImplementedError('override this method')

    def get_url(self):
        if self.url:
            return self.url
        else:
            return self._get_url()

    def set_id(self, id):
        self.objID = int(id)

    def set_title(self, title):
        if title is not None:
            title = title.split("/")[0]
            self.title = title
        else:
            self.title = self['title']

        self.title = self.title.strip()
        self['title'] = self.title

    def isSame(self, item):
        return self.objID == self.objID


# coding=utf-8
import sys

from filmweb.addon import BaseObject
from filmweb.parser.PersonParser import PersonParser
from filmweb.vars import filmweb_person_link


class Person(BaseObject):
    def __unicode__(self):
        """Return unicode title of Person"""
        return u"%s" % self.title

    def __repr__(self):
        """Return string representation of an object"""
        return u"<personID:%d title:_%s_>" % (self.objID, self.title.encode(sys.getdefaultencoding(), 'ignore'))

    __str__ = __repr__

    def _parser(self):
        return PersonParser(self)

    def _get_url(self):
        from filmweb.parser import HTMLGrabber

        grabber = HTMLGrabber()
        f = grabber.open(filmweb_person_link % ('name', self.objID))
        return f.url






# coding=utf-8


class FilmwebError(Exception):
    """Base class for every exception raised by the filmweb package."""


class FilmwebDataAccessError(FilmwebError):
    """Exception raised when is not possible to receive data."""
    pass


class FilmwebParserError(FilmwebError):
    """Exception raised when an error occurred parsing the data."""
    pass


# coding=utf-8
import re

try:
    from urllib import urlencode
except:
    from urllib.parse import urlencode

from bs4 import BeautifulSoup

from filmweb.Movie import Movie
from filmweb.Person import Person
from filmweb.parser.HTMLGrabber import HTMLGrabber
from filmweb.vars import filmweb_search_blank
from filmweb.vars import filmweb_person_search
from filmweb.func import get_real_id


class FilmwebHTTP(object):
    def _search_movie(self, title, results):
        """Return list of movies"""
        grabber = HTMLGrabber()
        li_list = []
        img_list = []
        params = {"q": title.encode("utf-8"), "page": 1}

        url = filmweb_search_blank + "?" + urlencode(params)

        content = grabber.retrieve(url)  # @Make search more pages not only 1
        soup = BeautifulSoup(content)
        li_list.extend(soup.findAll('div', {'class': 'hitDescWrapper'}))
        img_list.extend(soup.findAll('div', {'class': 'hitImage'}))

        for i, li in enumerate(li_list):
            a = li.find('a', {'class': 'hdr hdr-medium hitTitle'})
            title = a.text
            url = a['href']
            # have to do another check because sometimes url doesnt provide movieID
            aimg = img_list[i].find('a')
            if aimg is not None:
                img = aimg.find("img")
                movieID = get_real_id(url, img['src'])
                yield movieID, title, url

    def search_movie(self, title, results=20, ):
        try:
            results = int(results)
        except ValueError:
            results = 20

        return [Movie(objID=movieID, title=title, url=url) for movieID, title, url in
                self._search_movie(title, results, )]

    def search_filtered_movie(self, title=None, results=20, genre_id=None, search_type=None):
        if search_type not in ['film', 'serial']:
            search_type = None

        return [Movie(objID=movieID, title=title, url=url) for movieID, title, url in
                self._search_filtered_movie(title, results, genre_id, search_type)]

    def _search_filtered_movie(self, title, results, genre_id, search_type):

        grabber = HTMLGrabber()
        params = {}
        params['page'] = 1
        if title: params['q'] = title.encode("utf-8")
        if genre_id: params['genreIds'] = genre_id

        search_url = ""
        if search_type:
            search_url = "/" + search_type

        url = filmweb_search_blank + search_url + "?" + urllib.urlencode(params)

        content = grabber.retrieve(url)
        soup = BeautifulSoup(content)
        hits = soup.findAll('li', {'id': re.compile('hit_([0-9]*)')})
        for hit in hits:
            h3 = hit.find("h3")
            url = h3.find("a")['href']
            div_img = hit.find("div", {'class': 'filmPoster-1'})
            img = div_img.find("img")
            movieID = get_real_id(url, img['src'])

            yield movieID, title, url


    def _search_person(self, title, results=20):
        # http://www.filmweb.pl/search/person?q=Tom+Cruise
        """Return list of persons"""
        grabber = HTMLGrabber()
        p_title = grabber.encode_string(title)
        li_list = []
        img_list = []

        content = grabber.retrieve(filmweb_person_search % (p_title, 1))  #@Make search more pages not only 1
        soup = BeautifulSoup(content)
        li_list.extend(soup.findAll('div', {'class': 'hitDescWrapper'}))
        img_list.extend(soup.findAll('div', {'class': 'hitImage'}))

        for i, li in enumerate(li_list):
            a = li.find('a', {'class': 'hdr hdr-medium hitTitle'})
            title = a.text
            url = a['href']
            # have to do another check because sometimes url doesnt provide movieID
            aimg = img_list[i].find('a')
            if aimg is not None:
                img = aimg.find('img')
                personID = get_real_id(url, img['src'])
                yield personID, title, url

    def search_person(self, title, results=20):
        """Return list of persons"""
        try:
            results = int(results)
        except ValueError:
            results = 20

        return [Person(objID=personID, title=title, url=url) for personID, title, url in
                self._search_person(title, results)]

    def get_person(self, personID):
        return self._get_person(personID)

    def _get_person(self, personID):
        """Return Person object"""
        return Person(personID)

    def _get_movie(self, movieID):
        """Return Movie object"""
        return Movie(movieID)

    def get_movie(self, movieID):
        return self._get_movie(movieID)


# coding=utf-8
import datetime
import re

from bs4 import BeautifulSoup

from filmweb.Person import Person
from filmweb.func import get_text_or_none
from filmweb.parser.HTMLGrabber import HTMLGrabber
from filmweb.parser.ObjectParser import ObjectParser


class MovieParser(ObjectParser):
    def removeTag(self, soup, tagname):
        for tag in soup.findAll(tagname):
            contents = tag.contents
            parent = tag.parent
            tag.extract()


    def _parse_basic(self):
        dic = {}

        filmTitle = self.soup.find("div", {'class': "filmMainHeader"})
        title = filmTitle.find('a')

        dic['title'] = get_text_or_none(title)

        year = filmTitle.find('span', {'class': 'halfSize'})
        dic['year'] = get_text_or_none(year, 'int')

        s = filmTitle.find('h2')
        # self.removeTag(s,"span")
        dic['title_original'] = get_text_or_none(s)

        desc = self.soup.find('div', {'class': "filmPlot"})
        dic['desc'] = get_text_or_none(desc)

        poster = self.soup.find('div', {'class': 'posterLightbox'})
        if poster:
            p = poster.find("a")
            poster_img = p['href']
            dic['poster'] = poster_img
        else:
            dic['poster'] = None

        return dic

    def parse_genre(self):
        genres = [i.text for i in self.soup.find('div', {'class': 'filmInfo'}).findAll('a') if 'genre' in i['href']]
        return genres

    def parse_real_url(self):
        if self.obj.objID and self.obj.url is None:
            return self.obj.get_url()

    def parse_episodes(self):
        grabber = HTMLGrabber()
        content = grabber.retrieve(self.obj.url + "/episodes")
        soup = BeautifulSoup(content)
        seasons = soup.find('dl', {'class': 'episodesTable'})
        episodes_list = []
        for element in seasons.children:
            if element.name == 'dt':
                h3 = element.next_element
                try:
                    season_number = int(h3.text.split(" ")[1])
                except:
                    break
            if element.name == 'dd':
                li_episodes = element.find_all("li")
                for episode in li_episodes:
                    episode_number = int(re.match(r'\d+', episode.contents[0].text).group())
                    date_str = episode.find('div',{'class':'countryPremiereDate'}).text
                    episode_name = episode.find('div',{'class':'title'}).text
                    episode_date = datetime.datetime.strptime(date_str,'%d.%m.%Y')

                    episodes_list.append({'season': season_number, 'number': episode_number, 'date': episode_date, 'name': episode_name})
        return episodes_list


    def parse_cast(self):
        grabber = HTMLGrabber()
        content = grabber.retrieve(self.obj.url + "/cast/actors")
        soup = BeautifulSoup(content)
        cast_list_table = soup.find("table", {'class': 'filmCast'})
        cast_list = cast_list_table.find("tbody")


        personList = []
        for cast in cast_list_table.findAll('tr',id=re.compile("role_")):

            url_html = cast.find("a",{'class':'pImg49'})
            url = url_html['href']
            img_html = url_html.find("img")

            pattern_img = "http://1.fwcdn.pl/p/([0-9]{2})/([0-9]{2})/(?P<id>[0-9]*)/([0-9]*).([0-3]*).jpg"
            pattern_link = "/person/(.+)-(?P<id>[0-9]*)"



            results = re.search(pattern_link, url_html['href'])
            if results:
                id = results.group("id")
            else:
                results = re.search(pattern_img, repr(img_html.extract()))
                id = results.group("id")

            role_html  = cast.find('a',{'rel':'v:starring'})
            role = role_html.parent.nextSibling.nextSibling.text

            name = role_html.parent.nextSibling.text

            personList.append(Person(id, title=name, roleType='aktor', roleName=role, url=url))

            if cast.name == 'dt':
                roleType = cast.text.split("/")[0].strip()
                roleType
            elif cast.name == 'dd':
                castList = cast.findAll("li")
                for person in castList:

                    try:
                        role = person.find("span", {'class': 'roleName'}).text
                    except AttributeError:
                        role = None

                    name = person.find("span", {'class': 'personName'}).text

                    patternlink = "/person/(.+)-(?P<id>[0-9]*)"
                    patternimg = "http://1.fwcdn.pl/p/([0-9]{2})/([0-9]{2})/(?P<id>[0-9]*)/([0-9]*).([0-3]*).jpg"

                    href = person.find("span", {'class': 'personName'}).find("a")['href']

                    results = re.search(patternlink, href)
                    if results:
                        id = results.group("id")
                    else:
                        results = re.search(patternimg, repr(person.extract()))
                        id = results.group("id")

                    personList.append(Person(id, title=name, roleType=roleType, roleName=role, url=href))
        return personList

    def parse_additionalinfo(self):
        more_infos = []
        more_info = self.soup.find("div", {'class': "otherInfo"})
        more_info = more_info.find("dl")
        for more in more_info.findAll('dt'):
            if more.text not in(u'inne tytuły:',u'\xa0'):
                more_infos.append({'name': more.text.replace(":", ""), 'value': more.nextSibling.text})
        return more_infos

    def parse_basicinfo(self):
        basic_infos = []
        basic_info = self.soup.find("div", "filmInfo")
        for basic in basic_info.findAll('th'):
            if basic.text not in (u'\xa0',):
                basic_infos.append({'name': basic.text, 'value': basic.nextSibling.text})
        return basic_infos

    def parse_photos(self):
        grabber = HTMLGrabber()
        content = grabber.retrieve(self.obj.url + "/photos")
        soup = BeautifulSoup(content)
        photos_list = soup.find("ul", {'class','photosList'})
        images = []
        for photo in photos_list.findAll("img"):
            images.append({'href': photo.parent['href'], 'thumb': photo['src'], 'image': photo.parent['data-photo']})
        return images

    def parse_posters(self):
        grabber = HTMLGrabber()
        content = grabber.retrieve(self.obj.url + "/posters")
        soup = BeautifulSoup(content)
        photoList = soup.find("ul", 'block-list postersList')
        images = []
        for photo in photoList("img", {'class': "lbProxy"}):
            images.append({'href': photo['src'].replace(".2.jpg", '.3.jpg'), 'thumb': photo['src']})
        return images



# coding=utf-8
from filmweb._exceptions import FilmwebParserError
from filmweb.parser import FilmwebHTTP


def Filmweb(access='http'):
    if access == 'http':
        return FilmwebHTTP()
    else:
        raise FilmwebParserError('Unknown data system: %s' % access)



# coding=utf-8


try:
    import urllib2
except:
    import urllib.request as urllib2

try:
    from urllib import quote
except:
    from urllib.parse import quote

from filmweb._exceptions import FilmwebDataAccessError


class HTMLGrabber(object):
    def __init__(self, *args, **kwargs):
        self.headers = []
        self.set_header('User-agent', 'Googlebot/2.1 (+http://www.google.com/bot.html)')
        self.set_header('Referer', 'http://www.filmweb.pl/')
        self.set_header('Cookie', 'welcomeScreenNew=welcomeScreen')

    def set_header(self, header, value):
        """Set a header."""
        self.headers.append((header, value))

    def get_headers(self):
        return self.headers

    def encode_string(self, string):
        return quote(string.encode("utf-8"))

    def open(self, url):
        opener = urllib2.build_opener()
        opener.addheaders = self.get_headers()
        try:
            return opener.open(url)
        except (urllib2.HTTPError, urllib2.URLError):
            raise FilmwebDataAccessError()
        except ValueError:
            pass

    def retrieve(self, url):
        return self.open(url).read()


# coding=utf-8
import sys

from filmweb.addon import BaseObject
from filmweb.parser.MovieParser import MovieParser
from filmweb.vars import filmweb_movie_link


class Movie(BaseObject):
    def __unicode__(self):
        """Return unicode title of Movie"""
        return u"%s" % self.title

    def __repr__(self):
        """Return string representation of an object"""
        return u"<movieID:%d title:_%s_>" % (self.objID, self.title.encode(sys.getdefaultencoding(), 'ignore'))

    __str__ = __repr__

    def __contains__(self, item):
        """Return true if this Person has worked in the given Movie"""
        from filmweb.Person import Person

        if isinstance(item, Person):
            for cast in self['cast']:
                if cast.isSame(item): return True

        return False

    def _parser(self):
        return MovieParser(self)

    def _get_url(self):
        from filmweb.parser import HTMLGrabber

        grabber = HTMLGrabber()
        f = grabber.open(filmweb_movie_link % ('film', 2000, self.objID))
        return f.url





# coding=utf-8
import re
from datetime import datetime

from bs4 import BeautifulSoup

from filmweb.parser.HTMLGrabber import HTMLGrabber
from filmweb.vars import filmweb_search_blank


def get_real_id(*strings):
    for text in strings:
        text = str(text)

        found = re.search(
            "http://([0-9]{1,2}).fwcdn.pl/(p|po)/([0-9]{1,4})/([0-9]{1,4})/(?P<id>[0-9]{1,9})/([0-9]{1,9}).([0-9]{1}).jpg",
            text)
        if found is not None:
            return int(found.group('id'))

        found = re.search("dropdownTarget (?P<id>[0-9]*)_(FILM|SERIAL)", text)
        if found is not None:
            return int(found.group('id'))

        list = re.findall(r'-([0-9]*)', text)
        if len(list) and list[-1].isdigit():
            return int(list[-1])

    return 0


def get_canonical_name(title):
    splited = title.split(" ")
    name = splited[0]
    surname = splited[1:]
    surname.extend([name])

    return " ".join(surname)


def get_text_or_none(var, typ='str'):
    if typ == 'int':
        try:
            t = var.text[var.text.find('(') + 1:var.text.find(')')]
            return t
        except:
            return ''
    else:
        try:
            return var.text
        except:
            return ''


def get_datetime_or_none(txt):
    MONTHS = {u'stycznia': 1, u'lutego': 2, u'marca': 3, u'kwietnia': 4, u'maja': 5, u'czerwca': 6,
              u'lipca': 7, u'sierpnia': 8, u'września': 9, u'października': 10, u'listopada': 11, u'grudnia': 12
    }
    try:
        list = txt.text.split()
        month = MONTHS[list[1]]
        return datetime.strptime("%s-%d-%s" % (list[2], month, list[0]), "%Y-%m-%d")
    except:
        return None


def get_list_genres():
    grabber = HTMLGrabber()
    content = grabber.retrieve(filmweb_search_blank + "/film")
    soup = BeautifulSoup(content)
    genres = soup.findAll('input', {'name': 'genreIds'})
    list_genre = []
    for genre in genres:
        genre_id = genre.attrs['value']
        genre_name = genre.next_element.next_element.text
        list_genre.append({'genre_id': genre_id, 'genre_name': genre_name})
    return list_genre






# coding=utf-8
import unittest
from datetime import datetime

from filmweb import Filmweb
from filmweb.func import get_list_genres


def is_valid_url(url):
    import re
    regex = re.compile(
        r'^https?://'  # http:// or https://
        r'(?:(?:[A-Z0-9](?:[A-Z0-9-]{0,61}[A-Z0-9])?\.)+[A-Z]{2,6}\.?|'  # domain...
        r'localhost|'  # localhost...
        r'\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3})'  # ...or ip
        r'(?::\d+)?'  # optional port
        r'(?:/?|[/?]\S+)$', re.IGNORECASE)
    return url is not None and regex.search(url)

class Serialparser(unittest.TestCase):
    def setUp(self):
        self.fa = Filmweb('http')
        self.serial = self.fa.get_movie(33993)

    def test_in(self):
        found_movies = self.fa.search_movie('Przyjaciele')
        self.assertTrue(self.serial in found_movies)

    def test_year(self):
        self.assertEqual(self.serial['year'], '1994-2004')


class CheckMovieInfos(unittest.TestCase):
    def setUp(self):
        self.fa = Filmweb('http')
        self.movie = self.fa.get_movie(107552)

    def test_in(self):
        found_movies = self.fa.search_movie(u'Dziewczyna z sąsiedztwa')
        self.assertTrue(self.movie in found_movies)


class MovieNextTest(unittest.TestCase):
    def setUp(self):
        fw = Filmweb()
        self.movie = fw.get_movie(635169)

    def test_alllinkincast(self):
        for person in self.movie['cast']:
            self.assertNotEqual('http://www.filmweb.pl', person.url)
            self.assertIsNotNone(person.url)


class Movieparser(unittest.TestCase):
    def setUp(self):
        self.fa = Filmweb('http')
        self.movie = self.fa.get_movie(671)

    def test_in(self):
        found_movies = self.fa.search_movie('Leon zawodowiec')
        self.assertTrue(self.movie in found_movies)

    def test_cast(self):
        self.assertIsNotNone(self.movie['cast'])
        self.assertEqual(len(self.movie['cast']), 78)

        p = self.movie['cast'][0]
        self.assertEqual(p['title'], u'Jean Reno')
        self.assertEqual(p['roleName'], u'Léon')
        self.assertEqual(p['roleType'], u'aktor')
        self.assertEqual(p.objID, 88)

    def test_infos(self):
        self.assertEqual(len(self.movie['additionalinfo']), 5)

        self.assertEqual(len(self.movie['basicinfo']), 5)

        self.assertEqual(len(self.movie['photos']), 45)

        self.assertEqual('Leon zawodowiec', self.movie.title, )
        # self.assertEqual('Léon',self.movie['title_original'],)

    def test_year(self):
        self.assertEqual(self.movie['year'], '1994')


class Osobaparser(unittest.TestCase):
    def setUp(self):
        self.fa = Filmweb('http')
        self.osoba = self.fa.get_person(450)

    def test_infos(self):
        self.assertEqual('Kazimierz Kaczor', self.osoba.title, )
        self.assertEqual(self.osoba['birthdate'].month, 2)
        self.assertEqual(self.osoba['birthdate'].day, 9)
        self.assertEqual(self.osoba['birthdate'].year, 1941)
        self.assertIsNotNone(self.osoba.get('poster'))


    def test_in(self):
        found_osoby = self.fa.search_person("Kazimierz Kaczor")
        self.assertTrue(self.osoba in found_osoby)

    def test_filmography(self):
        filmography = self.osoba['filmography']
        self.assertGreater(len(self.osoba['filmography']), 0)

        film = filmography[0]
        self.assertEqual(film.objID, 742974)


class PosterEmptyTest(unittest.TestCase):
    def setUp(self):
        self.fa = Filmweb('http')
        self.osoba = self.fa.get_person(289000)

    def test_poster_and_name(self):
        self.assertIsNone(self.osoba.get('poster'))
        self.assertEqual(self.osoba['title'], u'David E. Browning')


class CanonicalnameTest(unittest.TestCase):
    def setUp(self):
        self.fa = Filmweb('http')
        self.karewicz = self.fa.get_person(461)  # Emil Karewicz
        self.kot = self.fa.get_person(148066)  # tomasz kot
        self.zmuda = self.fa.get_person(464409)  # marta zmuda trzebiatowska
        self.niro = self.fa.get_person(123)  # Robert De Niro
        self.hopkins = self.fa.get_person(48)  # Anthony Hopkins I

    def test_names(self):
        self.assertEqual(self.karewicz['canonicalname'], u'Karewicz Emil')
        self.assertEqual(self.kot['canonicalname'], u'Kot Tomasz')
        self.assertEqual(self.zmuda['canonicalname'], u'Żmuda Trzebiatowska Marta')
        self.assertEqual(self.niro['canonicalname'], u'De Niro Robert')
        self.assertEqual(self.hopkins['canonicalname'], u'Hopkins I Anthony')


class NadZycieTest(unittest.TestCase):
    def setUp(self):
        self.fa = Filmweb('http')
        self.movie = self.fa.get_movie(651141)

    def test_cast(self):
        self.assertIsNotNone(self.movie['cast'])
        p = self.movie['cast'][3]
        self.assertEqual(p['roleType'], u'aktor')

    def test_posters(self):
        self.assertEqual(len(self.movie['posters']), 2)

        for poster in self.movie['posters']:
            self.assertIsNotNone(is_valid_url(poster['href']))



class IxjanaTest(unittest.TestCase):
    def setUp(self):
        self.fa = Filmweb('http')
        self.movie = self.fa.get_movie(598624)

    def test_cast(self):
        self.assertIsNotNone(self.movie['cast'])
        p = self.movie['cast'][5]
        self.assertEqual(p['roleType'], u'aktor')


class EpisodesTest(unittest.TestCase):
    def setUp(self):
        self.fa = Filmweb('http')
        self.movie = self.fa.get_movie(130177)  # Dr House

    def test_episode(self):
        episode = self.movie['episodes'][47]
        self.assertEqual(episode['name'], u'Cane & Able')
        self.assertEqual(episode['season'], 3)
        self.assertEqual(episode['number'], 2)
        self.assertEqual(episode['date'], datetime.strptime("2006-09-12", "%Y-%m-%d"))


class GenresTest(unittest.TestCase):
    def setUp(self):
        self.fa = Filmweb('http')

    def test_genres_count(self):
        self.assertEqual(len(get_list_genres()), 66)

    """
    def test_search_genre(self):
        movie = self.fa.get_movie(32225)
        found_movies = self.fa.search_filtered_movie(title=None, results=20, genre_id=3, search_type='film')
        self.assertTrue(movie in found_movies)
    """


class XmenImagesGalleryTest(unittest.TestCase):
    def setUp(self):
        self.fa = Filmweb('http')
        self.movie = self.fa.get_movie(489280)

    def test_images(self):
        self.assertEqual(len(self.movie['photos']), 46)

        for photo in self.movie['photos']:
            self.assertIsNotNone(is_valid_url(photo['image']), msg=photo['image'])



from setuptools import setup

version = '0.1.5.1'

setup(name='filmwebpy',
      version=version,
      description="Python parser for Filmweb",
      long_description=open("README").read(),
      classifiers=[
          "Programming Language :: Python",
      ],
      keywords='python filmweb parser',
      author='Krzysztof Hoffmann',
      author_email='krzysztof.hoffmann@increase.pl',
      url='http://github.com/hoffmannkrzysztof/filmwebpy',
      license='GPL',
      packages=['filmweb', 'filmweb.parser'],
      namespace_packages=[],
      include_package_data=True,
      zip_safe=False,
      install_requires=[
          'setuptools', 'beautifulsoup4'
      ],
)



# coding=utf-8
from bs4 import BeautifulSoup


class ObjectParser(object):
    _soup = None
    _content = None

    def __init__(self, obj):
        self.obj = obj

    @property
    def content(self):
        if self._content is None:
            self._download_content(self.obj.url)
        return self._content

    @property
    def soup(self):
        if self._soup is None:
            self._download_content(self.obj.url)
        return self._soup

    def _download_content(self, url):
        from filmweb.parser.HTMLGrabber import HTMLGrabber

        grabber = HTMLGrabber()
        self._content = grabber.retrieve(url)
        self._soup = BeautifulSoup(self.content)

    def parse_basic(self):
        return self._parse_basic()

    def _parse_basic(self):
        """Parse basic information about movie or person. Eg. title, year, aka"""
        raise NotImplementedError('override this method')